module.exports = defineTest({
	description: 'declares updated variable in ES output (#755)',
	options: { output: { name: 'bundle' } }
});
